==> kubernetes-model-resource-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/PodSchedulingStatusFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSchedulingStatusFluent<A extends PodSchedulingStatusFluent<A>> extends Fluent<A>{
  public A addToResourceClaims(Integer index,ResourceClaimSchedulingStatus item);
  public A setToResourceClaims(Integer index,ResourceClaimSchedulingStatus item);
  public A addToResourceClaims(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimSchedulingStatus... items);
  public A addAllToResourceClaims(Collection<ResourceClaimSchedulingStatus> items);
  public A removeFromResourceClaims(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimSchedulingStatus... items);
  public A removeAllFromResourceClaims(Collection<ResourceClaimSchedulingStatus> items);
  public A removeMatchingFromResourceClaims(Predicate<ResourceClaimSchedulingStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceClaims instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceClaimSchedulingStatus> getResourceClaims();
  public List<ResourceClaimSchedulingStatus> buildResourceClaims();
  public ResourceClaimSchedulingStatus buildResourceClaim(Integer index);
  public ResourceClaimSchedulingStatus buildFirstResourceClaim();
  public ResourceClaimSchedulingStatus buildLastResourceClaim();
  public ResourceClaimSchedulingStatus buildMatchingResourceClaim(Predicate<ResourceClaimSchedulingStatusBuilder> predicate);
  public Boolean hasMatchingResourceClaim(Predicate<ResourceClaimSchedulingStatusBuilder> predicate);
  public A withResourceClaims(List<ResourceClaimSchedulingStatus> resourceClaims);
  public A withResourceClaims(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimSchedulingStatus... resourceClaims);
  public Boolean hasResourceClaims();
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> addNewResourceClaim();
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> addNewResourceClaimLike(ResourceClaimSchedulingStatus item);
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> setNewResourceClaimLike(Integer index,ResourceClaimSchedulingStatus item);
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> editResourceClaim(Integer index);
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> editFirstResourceClaim();
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> editLastResourceClaim();
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> editMatchingResourceClaim(Predicate<ResourceClaimSchedulingStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ResourceClaimsNested<N> extends Nested<N>,ResourceClaimSchedulingStatusFluent<PodSchedulingStatusFluent.ResourceClaimsNested<N>>{
    public N and();
    public N endResourceClaim();
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/PodSchedulingStatusFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSchedulingStatusFluent<A extends PodSchedulingStatusFluent<A>> extends Fluent<A>{
  public A addToResourceClaims(int index,ResourceClaimSchedulingStatus item);
  public A setToResourceClaims(int index,ResourceClaimSchedulingStatus item);
  public A addToResourceClaims(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimSchedulingStatus... items);
  public A addAllToResourceClaims(Collection<ResourceClaimSchedulingStatus> items);
  public A removeFromResourceClaims(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimSchedulingStatus... items);
  public A removeAllFromResourceClaims(Collection<ResourceClaimSchedulingStatus> items);
  public A removeMatchingFromResourceClaims(Predicate<ResourceClaimSchedulingStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceClaims instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceClaimSchedulingStatus> getResourceClaims();
  public List<ResourceClaimSchedulingStatus> buildResourceClaims();
  public ResourceClaimSchedulingStatus buildResourceClaim(int index);
  public ResourceClaimSchedulingStatus buildFirstResourceClaim();
  public ResourceClaimSchedulingStatus buildLastResourceClaim();
  public ResourceClaimSchedulingStatus buildMatchingResourceClaim(Predicate<ResourceClaimSchedulingStatusBuilder> predicate);
  public Boolean hasMatchingResourceClaim(Predicate<ResourceClaimSchedulingStatusBuilder> predicate);
  public A withResourceClaims(List<ResourceClaimSchedulingStatus> resourceClaims);
  public A withResourceClaims(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimSchedulingStatus... resourceClaims);
  public Boolean hasResourceClaims();
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> addNewResourceClaim();
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> addNewResourceClaimLike(ResourceClaimSchedulingStatus item);
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> setNewResourceClaimLike(int index,ResourceClaimSchedulingStatus item);
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> editResourceClaim(int index);
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> editFirstResourceClaim();
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> editLastResourceClaim();
  public PodSchedulingStatusFluent.ResourceClaimsNested<A> editMatchingResourceClaim(Predicate<ResourceClaimSchedulingStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ResourceClaimsNested<N> extends Nested<N>,ResourceClaimSchedulingStatusFluent<PodSchedulingStatusFluent.ResourceClaimsNested<N>>{
    public N and();
    public N endResourceClaim();
    
  }
  
}
